# -*- coding: utf-8 -*-
import irc3

from docopt import Dict as DocOptDict
from irc3.plugins.command import command
from irc3.utils import IrcString

from . import DatabasePlugin
from ..utils import parse_int


class McManiac(DatabasePlugin):
    requires = ['irc3.plugins.command',
                'nxy.plugins.database']
    table = 'mcmaniacs'

    @command(options_first=True)
    def mcmaniac(self, mask: IrcString, channel: IrcString, args: DocOptDict):
        """Get a random McManiaC or by index.

        %%mcmaniac [<index>]
        """
        index = args.get('<index>')
        if index:
            index = parse_int(index)
            if not index:
                return
            index, order, _ = index
            order = 'id {order}'.format(order=order)
            extra = 'offset ?'
            binds = [index]
        else:
            order = 'random()'
            extra = ''
            binds = []
        self.cur.execute('''select item,
        (select count(id) from mcmaniacs b where a.id >= b.id) as idx,
        (select count(id) from mcmaniacs) as len
        from mcmaniacs a order by {order} limit 1 {extra}
        '''.format(order=order, extra=extra), binds)
        result = self.cur.fetchone()
        if result:
            return '[{idx}/{len}] {item}'.format(**result)

    @irc3.event(r'(?i)^:(?P<mask>\S+) PRIVMSG \S+ :.*(?P<item>Mc\S+iaC).*')
    def save(self, mask: str, item: str):
        if IrcString(mask).nick != self.bot.nick:
            self.cur.execute('insert into mcmaniacs (item) values (?)', [item])
            self.con.commit()
